@@ -1,4 +1,5 @@
-from ..models import (ComponentHasNoEntity, ComponentAlreadyHaveEntity)
+from ..models import (ComponentHasNoEntity, ComponentAlreadyHaveEntity,
+                      EntityAlredyHaveComponent)
 
 
 class ComponentManager():
@@ -20,6 +21,7 @@ class ComponentManager():
 
     def create_component(self, component):
         if component in self._components:
+            # TO DO: fix this error
             raise ComponentAlreadyHaveEntity(component)
 
         component._id = self._component_count
@@ -29,7 +31,12 @@ class ComponentManager():
 
         if self._component_types.get(component.type) is None:
             self._component_types[component.type] = {}
-        self._component_types[component.type][component.id] = component
+
+        if self._component_types[component.type].get(component.entity.id) \
+                                                                    is not None:
+            EntityAlredyHaveComponent(component.entity, component)
+
+        self._component_types[component.type][component.entity.id] = component
 
     def destroy_component(self, component):
         if component not in self._components:
@@ -37,6 +44,6 @@ class ComponentManager():
 
         self._components[component.id] = None
 
-        del self._component_types[component.type][component.id]
+        del self._component_types[component.type][component.entity.id]
         if self._component_types[component.type] == {}:
             del self._component_types[component.type]
